Learn R Programming

litterfitter (version 0.1.4)

predict.litfit: Predict method for litfit objects

Description

Generated predicted values for (new) time points from a litfit model fit

Usage

# S3 method for litfit
predict(object,newdata=NULL,...)

Value

predicted values from a litfit object

Arguments

object

litfit object

newdata

optional vector of new Time points at which to predict mass remaining. If not specified, Time points from the original fit are used.

...

further arguments passed to or from other methods.

Author

Will Cornwell

James Weedon

Details

to do

See Also

fit_litter

Examples

Run this code
fit<-fit_litter(time=c(0,1,2,3,4,5,6),mass.remaining=c(1,0.9,1.01,0.4,0.6,0.2,0.01),
'neg.exp',iters=250)
predict(fit, newdata=1:10)

Run the code above in your browser using DataLab