powered by
Generated predicted values for (new) time points from a litfit model fit
# S3 method for litfit predict(object,newdata=NULL,...)
predicted values from a litfit object
litfit object
optional vector of new Time points at which to predict mass remaining. If not specified, Time points from the original fit are used.
further arguments passed to or from other methods.
Will Cornwell
James Weedon
to do
fit_litter
fit<-fit_litter(time=c(0,1,2,3,4,5,6),mass.remaining=c(1,0.9,1.01,0.4,0.6,0.2,0.01), 'neg.exp',iters=250) predict(fit, newdata=1:10)
Run the code above in your browser using DataLab